Region

Enum Region 

pub enum Region {
Show 56 variants Argentina, Austria, Australia, Belgium, Brazil, Canada, Switzerland, Chile, China, Czechia, Germany, Denmark, Estonia, Egypt, Spain, Finland, France, UnitedKingdom, Greece, HongKongSarChina, Hungary, Indonesia, Ireland, Israel, India, Iceland, Italy, Japan, SouthKorea, Kuwait, SriLanka, Lithuania, Latvia, Mexico, Malaysia, Netherlands, Norway, NewZealand, Peru, Philippines, Pakistan, Poland, Portugal, Qatar, Russia, SaudiArabia, Sweden, Singapore, Suriname, Thailand, Turkey, Taiwan, UnitedStates, Venezuela, Vietnam, SouthAfrica,
}

Variants



Argentina



Austria



Australia



Belgium



Brazil



Canada



Switzerland



Chile



China



Czechia



Germany



Denmark



Estonia



Egypt



Spain



Finland



France



UnitedKingdom



Greece



HongKongSarChina



Hungary



Indonesia



Ireland



Israel



India



Iceland



Italy



Japan



SouthKorea



Kuwait



SriLanka



Lithuania



Latvia



Mexico



Malaysia



Netherlands



Norway



NewZealand



Peru



Philippines



Pakistan



Poland



Portugal



Qatar



Russia



SaudiArabia



Sweden



Singapore



Suriname



Thailand



Turkey



Taiwan



UnitedStates



Venezuela



Vietnam



SouthAfrica

Implementations

Source

impl Region

pub fn full_name(&self) -> &'static str